# Svix
The Svix client API documentation

Please refer to [the documentation](https://docs.svix.com/) for usage instructions.


## Development

### Install Deps

```sh
python -m venv .venv
pip install -r requirements.txt && pip install -r requirements-dev.txt
```

### Run Tests

```sh
pytest
```